### What this repository contains

A Command Line Interface to save openapi file from a FastAPI application

### Installation: 

install the package
```
pip install fastapi-openapi-generator
```

### How to use
```
fastapi-openapi-gen main:app \
    --app-dir= # The path to mounth in the python path to import the module \
    --output-dir= # The path where store the openapi template
```
